summaryrefslogtreecommitdiffstats
path: root/kpresenter/KPrView.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commit7c71ab86d1f7e387fc3df63b48df07231f111862 (patch)
tree30ba2d2f840ff5fd458b6113e9c3f2e8a71d510d /kpresenter/KPrView.cpp
parentafbfdc507bfaafc8824a9808311d57a9ece87510 (diff)
downloadkoffice-7c71ab86d1f7e387fc3df63b48df07231f111862.tar.gz
koffice-7c71ab86d1f7e387fc3df63b48df07231f111862.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kpresenter/KPrView.cpp')
-rw-r--r--kpresenter/KPrView.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kpresenter/KPrView.cpp b/kpresenter/KPrView.cpp
index 7382cc5e..9577bc7d 100644
--- a/kpresenter/KPrView.cpp
+++ b/kpresenter/KPrView.cpp
@@ -4819,15 +4819,15 @@ TQPopupMenu * KPrView::popupMenu( const TQString& name )
}
void KPrView::addVariableActions( int type, const TQStringList & texts,
- KActionMenu * tqparentMenu, const TQString & menuText )
+ KActionMenu * parentMenu, const TQString & menuText )
{
// Single items go directly into tqparentMenu.
// For multiple items we create a submenu.
if ( texts.count() > 1 && !menuText.isEmpty() )
{
KActionMenu * subMenu = new KActionMenu( menuText, actionCollection() );
- tqparentMenu->insert( subMenu );
- tqparentMenu = subMenu;
+ parentMenu->insert( subMenu );
+ parentMenu = subMenu;
}
TQStringList::ConstIterator it = texts.begin();
for ( int i = 0; it != texts.end() ; ++it, ++i )
@@ -4840,7 +4840,7 @@ void KPrView::addVariableActions( int type, const TQStringList & texts,
KAction * act = new KAction( (*it), 0, TQT_TQOBJECT(this), TQT_SLOT( insertVariable() ),
actionCollection(), "var-action" );
m_variableDefMap.insert( act, v );
- tqparentMenu->insert( act );
+ parentMenu->insert( act );
}
}
}
@@ -4819,15 +4819,15 @@ TQPopupMenu * KPrView::popupMenu( const TQString& name )
{
- // Single items go directly into tqparentMenu.
+ // Single items go directly into parentMenu.
// For multiple items we create a submenu.
if ( texts.count() > 1 && !menuText.isEmpty() )